@@ -28,7 +28,7 @@ from kivy.core.window import Window  # pylint: disable=wrong-import-order
 from kivy.uix.textinput import TextInput  # pylint: disable=wrong-import-order
 
 MY_COMPUTER = "chris-mbp"
-SERVER = ["secureerase", MY_COMPUTER]
+SERVER = ["secureerase", "secureerase.local", MY_COMPUTER]
 print(platform.node().lower())
 if platform.node().lower() == MY_COMPUTER:
     config.DEBUG_CODE = True
@@ -106,7 +106,7 @@ class MainScreen(Screen):
         self.grid_layout.add_widget(start_discord_bot_button)
         self.add_widget(self.grid_layout)
 
-        if platform.node().lower() in SERVER or f"{platform.node().lower()}.local" in SERVER:
+        if platform.node().lower() in SERVER:
             self.start_api_server(start_api_server_button)
             self.start_discord_bot(start_discord_bot_button)
 
